Raporty i rankingi
------------------

Ranking autorów
~~~~~~~~~~~~~~~

Do rankingu autorów wchodzą prace z jednostek, które mają zaznaczone pole "Wchodzi do raportów".
Pole to domyślnie przyjmuje wartość "PRAWDA".

Do rankingu autorów nie wchodzą prace, których skrót typu KBN to "PW" (praca wieloośrodkowa).
